@@ -21,4 +21,4 @@ class Accuracy(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0.001):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(Accuracy, self).__init__(default, min_value=0)
