@@ -21,4 +21,4 @@ class Granularity(XMLInteger):
     _TYPE = 'sdf'
 
     def __init__(self, default=1):
-        XMLInteger.__init__(self, default, min_value=0)
+        super(Granularity, self).__init__(default, min_value=0)
