@@ -21,4 +21,4 @@ class HorizontalFOV(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=1.047):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(HorizontalFOV, self).__init__(default, min_value=0)
