@@ -21,7 +21,7 @@ class Kd(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=1):
-        XMLScalar.__init__(self, default)
+        super(Kd, self).__init__(default)
 
     def _set_value(self, value):
         assert self._is_scalar(value), \
